==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/SAPDB/Trace/Trace_Wrapper.cpp <==
/*!**************************************************************************

  module      : Trace_Wrapper.cpp

  -------------------------------------------------------------------------

  responsible : TorstenS

  special area:
  description : 

  last changed: 2000-12-21  13:48
  see also    :

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"   // PASCAL: SP_basic_constants_and_types
#include "ggg00.h"   // PASCAL: GG_kernel_constants_and_types
#include "heo58.h"   // RTE   : vIsTraceWanted


#include "SAPDB/Trace/Trace_Entry.hpp"
#include "SAPDB/Trace/Trace_Manager.hpp"
#include "SAPDB/Trace/Trace_MessBlockEntry.hpp"
#include "SAPDB/Trace/Trace_PacketEntry.hpp"
#include "SAPDB/Trace/Trace_Writer.hpp"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/

#define TRUE    1

/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/



/*===========================================================================*
 *  GLOBAL VARIABLES                                                         *
 *===========================================================================*/



/*===========================================================================*
 *  LOCAL CLASSES, STRUCTURES, TYPES, UNIONS ...                             *
 *===========================================================================*/



/*===========================================================================*
 *  STATIC/INLINE FUNCTIONS (PROTOTYPES)                                     *
 *===========================================================================*/



/*===========================================================================*
 *  METHODS                                                                  *
 *===========================================================================*/

/*---------------------------------------------------------------------------*/
/* Singleton Pascal Wrapper Functionality                                    */
/*---------------------------------------------------------------------------*/

externC void b120CreateTrace( tgg00_TransContext &Trans )
{ 
    if ( true != Trace_Manager::CreateInstance( Trans.trTaskId_gg00 ))
      Trans.trError_gg00 = e_sysbuf_storage_exceeded;
};

/*---------------------------------------------------------------------------*/

externC void b120TraceWriter( tgg00_TransContext &Trans  )
{
    
    if ( true != Trace_Writer::CreateInstance( Trans.trTaskId_gg00  ))
        Trans.trError_gg00 = e_sysbuf_storage_exceeded;
    
    Trace_Writer::GetInstance().Run();
};

/*---------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------*/

externC void b120ClearTrace( tsp00_TaskId TaskId )
{
    Trace_Manager::GetInstance().PrepareAndWaitForFlush( TaskId, TRUE );
};

/*---------------------------------------------------------------------------*/

externC void b120FlushTrace( tsp00_TaskId TaskId )
{
    Trace_Manager::GetInstance().PrepareAndWaitForFlush( TaskId );
}

/*---------------------------------------------------------------------------*/

externC tsp00_Bool b120KernelStopped()
{
    return( TRUE == vIsTraceWanted() );
};

/*---------------------------------------------------------------------------*/

externC void b120MessBlockTrace ( 
                                 tgg00_TransContext    &Trans,
                                 tgg00_VtraceType_Param Type,
                                 tgg00_MessBlock       &MessBlock )
{
    tgg00_Debug Layer = tgg00_Debug::fromConst( ak_messbuf );
    
    Trace_MessBlockEntry Entry( Trans, MessBlock, Layer,
                                tgg00_VtraceType::fromConst(Type) );
};
 
/*---------------------------------------------------------------------------*/

externC void b120MoveObjectTrace(
                                 tgg00_TransContext &Trans,
                                 tgg00_Debug_Param  Layer,
                                 tgg00_VtraceType_Param Type,
                                 tsp00_Int4         Length,
                                 tsp00_BytePtr      pEntry )
{
    Trace_PacketEntry Entry( Trans, tgg00_Debug::fromConst(Layer),
                             tgg00_VtraceType::fromConst(Type), pEntry, Length );
};

/*---------------------------------------------------------------------------*/

externC void b120InsertTrace(
                       tgg00_TransContext   &Trans,
                       tgg00_Debug_Param    Layer,
                       tgg00_VtraceType_Param Type,
                       tsp00_Int4           Length,
                       tsp00_BytePtr        pEntry )
{
    Trace_CommonEntry Entry( Trans, tgg00_Debug::fromConst(Layer),
                             tgg00_VtraceType::fromConst(Type), pEntry, Length );
};

/*===========================================================================*
 *  END OF CODE                                                              *
 *===========================================================================*/

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/SAPDB/Trace/Trace_Wrapper.cpp <==
/*!**************************************************************************

  module      : Trace_Wrapper.cpp

  -------------------------------------------------------------------------

  responsible : TorstenS

  special area:
  description : 

  last changed: 2000-12-21  13:48
  see also    :

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"   // PASCAL: SP_basic_constants_and_types
#include "ggg00.h"   // PASCAL: GG_kernel_constants_and_types
#include "gsp03.h"
#include "hgg01_1.h"


#include "SAPDBCommon/SAPDB_Types.hpp"
#include "Trace/Trace_Entry.hpp"
#include "Trace/Trace_Manager.hpp"
#include "Trace/Trace_MessBlockEntry.hpp"
#include "Trace/Trace_PacketEntry.hpp"
#include "Trace/Trace_Writer.hpp"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/

#define ALLOCATE_FAILED_MSG1 "TraceManager: bad alloc "
#define ALLOCATE_FAILED_MSG2 "TraceWriter: bad alloc  "

/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/



/*===========================================================================*
 *  GLOBAL VARIABLES                                                         *
 *===========================================================================*/



/*===========================================================================*
 *  LOCAL CLASSES, STRUCTURES, TYPES, UNIONS ...                             *
 *===========================================================================*/



/*===========================================================================*
 *  STATIC/INLINE FUNCTIONS (PROTOTYPES)                                     *
 *===========================================================================*/



/*===========================================================================*
 *  METHODS                                                                  *
 *===========================================================================*/

/*---------------------------------------------------------------------------*/
/* Singleton Pascal Wrapper Functionality                                    */
/*---------------------------------------------------------------------------*/

externC void b120CreateTrace( tsp00_TaskId TaskId )
{ 
    if ( true != Trace_Manager::CreateInstance( TaskId ))
        g01abort (csp3_allocat, csp3_n_memory, ALLOCATE_FAILED_MSG1, 0);
    
};

/*---------------------------------------------------------------------------*/

externC void b120TraceWriter( tsp00_TaskId TaskId   )
{
    
    if ( true != Trace_Writer::CreateInstance( TaskId  ))
        g01abort (csp3_allocat, csp3_n_memory, ALLOCATE_FAILED_MSG2, 0);
    
    Trace_Writer::GetInstance().Run();
};

/*---------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------*/

externC void b120WriteUserForcedDump( 
                                     tsp00_TaskId              TaskId,
                                     const tsp00_VFilename     &FileName,
                                     tgg00_DumpStateSet        &DumpStateSet )
{
    Trace_Writer::GetInstance().UserForcedDump( TaskId, FileName, DumpStateSet );
}

/*---------------------------------------------------------------------------*/

externC void b120ClearTrace( tsp00_TaskId TaskId )
{
    Trace_Manager::GetInstance().PrepareAndWaitForFlush( TaskId, true );
};

/*---------------------------------------------------------------------------*/

externC void b120FlushTrace( tsp00_TaskId TaskId )
{
    Trace_Manager::GetInstance().PrepareAndWaitForFlush( TaskId );
}

/*---------------------------------------------------------------------------*/

externC void b120MessBlockTrace ( 
                                 tgg00_TransContext    &Trans,
                                 tgg00_VtraceType_Param Type,
                                 tgg00_MessBlock       &MessBlock )
{
    tgg00_Debug Layer = tgg00_Debug::fromConst( ak_messbuf );
    
    Trace_MessBlockEntry Entry( Trans, MessBlock, Layer,
                                tgg00_VtraceType::fromConst(Type) );
};
 
/*---------------------------------------------------------------------------*/

externC void b120MoveObjectTrace(
                                 tgg00_TransContext &Trans,
                                 tgg00_Debug_Param  Layer,
                                 tgg00_VtraceType_Param Type,
                                 SAPDB_Int4         Length,
                                 tsp00_BytePtr      pEntry )
{
    Trace_PacketEntry Entry( Trans, tgg00_Debug::fromConst(Layer),
                             tgg00_VtraceType::fromConst(Type), pEntry, Length );
};

/*---------------------------------------------------------------------------*/

externC void b120InsertTrace(
                       tgg00_TransContext   &Trans,
                       tgg00_Debug_Param    Layer,
                       tgg00_VtraceType_Param Type,
                       SAPDB_Int4           Length,
                       tsp00_BytePtr        pEntry )
{
    Trace_CommonEntry Entry( Trans, tgg00_Debug::fromConst(Layer),
                             tgg00_VtraceType::fromConst(Type), pEntry, Length );
};

/*===========================================================================*
 *  END OF CODE                                                              *
 *===========================================================================*/
